#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'QTerminal.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/qterminal/libqterminal/QTerminal.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QTerminal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QTerminal_t {
    QByteArrayData data[25];
    char stringdata0[410];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QTerminal_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QTerminal_t qt_meta_stringdata_QTerminal = {
    {
QT_MOC_LITERAL(0, 0, 9), // "QTerminal"
QT_MOC_LITERAL(1, 10, 21), // "report_status_message"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 16), // "interrupt_signal"
QT_MOC_LITERAL(4, 50, 18), // "edit_mfile_request"
QT_MOC_LITERAL(5, 69, 15), // "show_doc_signal"
QT_MOC_LITERAL(6, 85, 34), // "execute_command_in_terminal_s..."
QT_MOC_LITERAL(7, 120, 13), // "copyClipboard"
QT_MOC_LITERAL(8, 134, 14), // "pasteClipboard"
QT_MOC_LITERAL(9, 149, 9), // "selectAll"
QT_MOC_LITERAL(10, 159, 32), // "handleCustomContextMenuRequested"
QT_MOC_LITERAL(11, 192, 2), // "at"
QT_MOC_LITERAL(12, 195, 15), // "notice_settings"
QT_MOC_LITERAL(13, 211, 19), // "const gui_settings*"
QT_MOC_LITERAL(14, 231, 8), // "settings"
QT_MOC_LITERAL(15, 240, 18), // "init_terminal_size"
QT_MOC_LITERAL(16, 259, 18), // "terminal_interrupt"
QT_MOC_LITERAL(17, 278, 20), // "set_global_shortcuts"
QT_MOC_LITERAL(18, 299, 9), // "focus_out"
QT_MOC_LITERAL(19, 309, 13), // "run_selection"
QT_MOC_LITERAL(20, 323, 9), // "edit_file"
QT_MOC_LITERAL(21, 333, 13), // "edit_selected"
QT_MOC_LITERAL(22, 347, 18), // "help_on_expression"
QT_MOC_LITERAL(23, 366, 17), // "doc_on_expression"
QT_MOC_LITERAL(24, 384, 25) // "handle_visibility_changed"

    },
    "QTerminal\0report_status_message\0\0"
    "interrupt_signal\0edit_mfile_request\0"
    "show_doc_signal\0execute_command_in_terminal_signal\0"
    "copyClipboard\0pasteClipboard\0selectAll\0"
    "handleCustomContextMenuRequested\0at\0"
    "notice_settings\0const gui_settings*\0"
    "settings\0init_terminal_size\0"
    "terminal_interrupt\0set_global_shortcuts\0"
    "focus_out\0run_selection\0edit_file\0"
    "edit_selected\0help_on_expression\0"
    "doc_on_expression\0handle_visibility_changed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QTerminal[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  109,    2, 0x06 /* Public */,
       3,    0,  112,    2, 0x06 /* Public */,
       4,    2,  113,    2, 0x06 /* Public */,
       5,    1,  118,    2, 0x06 /* Public */,
       6,    1,  121,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,  124,    2, 0x0a /* Public */,
       8,    0,  125,    2, 0x0a /* Public */,
       9,    0,  126,    2, 0x0a /* Public */,
      10,    1,  127,    2, 0x0a /* Public */,
      12,    1,  130,    2, 0x0a /* Public */,
      15,    0,  133,    2, 0x0a /* Public */,
      16,    0,  134,    2, 0x0a /* Public */,
      17,    1,  135,    2, 0x0a /* Public */,
      19,    0,  138,    2, 0x0a /* Public */,
      20,    0,  139,    2, 0x0a /* Public */,
      21,    0,  140,    2, 0x0a /* Public */,
      22,    0,  141,    2, 0x0a /* Public */,
      23,    0,  142,    2, 0x0a /* Public */,
      24,    1,  143,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   11,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void QTerminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QTerminal *_t = static_cast<QTerminal *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->report_status_message((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->interrupt_signal(); break;
        case 2: _t->edit_mfile_request((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->execute_command_in_terminal_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->copyClipboard(); break;
        case 6: _t->pasteClipboard(); break;
        case 7: _t->selectAll(); break;
        case 8: _t->handleCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 9: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 10: _t->init_terminal_size(); break;
        case 11: _t->terminal_interrupt(); break;
        case 12: _t->set_global_shortcuts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->run_selection(); break;
        case 14: _t->edit_file(); break;
        case 15: _t->edit_selected(); break;
        case 16: _t->help_on_expression(); break;
        case 17: _t->doc_on_expression(); break;
        case 18: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (QTerminal::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::report_status_message)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (QTerminal::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::interrupt_signal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (QTerminal::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::edit_mfile_request)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (QTerminal::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::show_doc_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (QTerminal::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QTerminal::execute_command_in_terminal_signal)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject QTerminal::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_QTerminal.data,
      qt_meta_data_QTerminal,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QTerminal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTerminal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QTerminal.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int QTerminal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void QTerminal::report_status_message(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QTerminal::interrupt_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QTerminal::edit_mfile_request(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QTerminal::show_doc_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QTerminal::execute_command_in_terminal_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
